spacepy.time.doy2date — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »

# spacepy.time.doy2date

`spacepy.time.` `doy2date`(year, doy, dtobj=False, flAns=False)

  convert integer day-of-year doy into a month and day after http://pleac.sourceforge.net/pleac_python/datesandtimes.html

  Parameters: | year : int or array of int year doy : int or array of int day of year
  Returns: | month : int or array of int month as integer number day : int or array of int as integer number

  See also

  `Ticktock.getDOY`

  Examples

      >>> month, day = doy2date(2002, 186)
      >>> dts = doy2date([2002]*4, range(186,190), dtobj=True)

### Navigation

- index
- modules |
- modules |
- next |
- homepage|
- search|
- documentation »
- time - Time conversion, manipulation and implementation of Ticktock class »